@@ -22,19 +22,22 @@ asyncio.run(dataset.attach())
 job = asyncio.run(
     trainml_client.jobs.create(
         name="Example Training Job",
-        type="headless",
-        gpu_type="GTX 1060",
+        type="training",
+        gpu_type="gtx1060",
         gpu_count=1,
         disk_size=10,
         workers=[
-            "PYTHONPATH=$PYTHONPATH:$TRAINML_MODEL_PATH python -m official.vision.image_classification.resnet_cifar_main --num_gpus=1 --data_dir=$TRAINML_DATA_PATH --model_dir=$TRAINML_OUTPUT_PATH --enable_checkpoint_and_export=True --train_epochs=10 --batch_size=1024",
+            "python training/image-classification/resnet_cifar.py --epochs 10 --optimizer adam --batch-size 128",
         ],
         data=dict(
             datasets=[dict(id=dataset.id, type="existing")],
             output_uri="s3://trainml-examples/output/resnet_cifar10",
             output_type="aws",
         ),
-        model=dict(git_uri="git@github.com:trainML/test-private.git"),
+        model=dict(
+            source_type="git",
+            source_uri="https://github.com/trainML/examples.git",
+        ),
     )
 )
 print(job)
