@@ -36,14 +36,14 @@ async def run_job(dataset):
         gpu_count=1,
         disk_size=10,
         workers=[
-            "PYTHONPATH=$PYTHONPATH:$TRAINML_MODEL_PATH python -m official.vision.image_classification.resnet_cifar_main --num_gpus=1 --data_dir=$TRAINML_DATA_PATH --model_dir=$TRAINML_OUTPUT_PATH --enable_checkpoint_and_export=True --train_epochs=10 --batch_size=1024",
+            "python training/image-classification/resnet_cifar.py --epochs 10 --optimizer adam --batch-size 128",
         ],
         data=dict(
             datasets=[dict(id=dataset.id, type="existing")],
             output_uri="~/tensorflow-example/output",
             output_type="local",
         ),
-        model=dict(source_type="local", source_uri="~/tensorflow-model"),
+        model=dict(source_type="local", source_uri="~/trainml-examples"),
     )
 
     print(job)
