@@ -27,6 +27,7 @@ def job(mock_trainml):
         mock_trainml,
         **{
             "customer_uuid": "cus-id-1",
+            "project_uuid": "proj-id-1",
             "job_uuid": "job-id-1",
             "name": "test notebook",
             "start": "2021-02-11T15:46:22.455Z",
@@ -102,6 +103,7 @@ def training_job(mock_trainml):
         mock_trainml,
         **{
             "customer_uuid": "cus-id-1",
+            "project_uuid": "proj-id-1",
             "job_uuid": "job-id-1",
             "name": "test training",
             "start": "2021-02-11T15:46:22.455Z",
@@ -273,6 +275,7 @@ class JobsTests:
             disk_size=10,
         )
         expected_payload = dict(
+            project_uuid="proj-id-a",
             name="job_name",
             type="notebook",
             resources=dict(
@@ -309,6 +312,7 @@ class JobsTests:
         )
         expected_payload = dict(
             name="job_name",
+            project_uuid="proj-id-a",
             type="notebook",
             resources=dict(
                 gpu_type_id="1060-id", gpu_count=1, disk_size=10, max_price=2
@@ -391,6 +395,8 @@ class JobTests:
     def test_job_get_connection_details_no_data(self, job):
         details = job.get_connection_details()
         expected_details = dict(
+            project_uuid="proj-id-1",
+            entity_type="job",
             cidr="10.106.171.0/24",
             ssh_port=None,
             model_path=None,
@@ -404,6 +410,7 @@ class JobTests:
             mock_trainml,
             **{
                 "customer_uuid": "cus-id-1",
+                "project_uuid": "proj-id-1",
                 "job_uuid": "job-id-1",
                 "name": "test notebook",
                 "type": "notebook",
@@ -429,6 +436,8 @@ class JobTests:
         )
         details = job.get_connection_details()
         expected_details = dict(
+            project_uuid="proj-id-1",
+            entity_type="job",
             cidr="10.106.171.0/24",
             ssh_port=46600,
             model_path=None,
@@ -444,6 +453,7 @@ class JobTests:
             mock_trainml,
             **{
                 "customer_uuid": "cus-id-1",
+                "project_uuid": "proj-id-1",
                 "job_uuid": "job-id-1",
                 "name": "test notebook",
                 "type": "notebook",
@@ -469,6 +479,8 @@ class JobTests:
         )
         details = job.get_connection_details()
         expected_details = dict(
+            project_uuid="proj-id-1",
+            entity_type="job",
             cidr="10.106.171.0/24",
             ssh_port=46600,
             model_path="~/model_dir",
