@@ -7,10 +7,11 @@ with warnings.catch_warnings():
     from .trainml import TrainML
 
 logging.basicConfig(
-    format="%(asctime)s %(message)s", datefmt="%m/%d/%Y %I:%M:%S %p"
+    format="%(asctime)s  %(levelname)s  %(message)s",
+    datefmt="%m/%d/%Y %I:%M:%S %p",
 )
 logger = logging.getLogger(__name__)
 
 
-__version__ = "0.4.0"
+__version__ = "0.4.1"
 __all__ = "TrainML"
