@@ -106,6 +106,8 @@ class Dataset:
     def get_connection_details(self):
         if self._dataset.get("vpn"):
             details = dict(
+                entity_type="dataset",
+                project_uuid=self._dataset.get("project_uuid"),
                 cidr=self._dataset.get("vpn").get("cidr"),
                 ssh_port=self._dataset.get("vpn")
                 .get("client")
@@ -118,6 +120,11 @@ class Dataset:
         return details
 
     async def connect(self):
+        if self.status in ["ready", "failed"]:
+            raise SpecificationError(
+                "status",
+                f"You can only connect to new or downloading datasets.",
+            )
         connection = Connection(
             self.trainml, entity_type="dataset", id=self.id, entity=self
         )
