@@ -280,6 +280,8 @@ class Job:
 
     def get_connection_details(self):
         details = dict(
+            entity_type="job",
+            project_uuid=self._job.get("project_uuid"),
             cidr=self.dict.get("vpn").get("cidr"),
             ssh_port=self._job.get("vpn").get("client").get("ssh_port")
             if self._job.get("vpn").get("client")
@@ -308,6 +310,7 @@ class Job:
         if self.type == "notebook" and self.status not in [
             "new",
             "waiting for data/model download",
+            "waiting for GPUs",
         ]:
             raise SpecificationError(
                 "type",
@@ -318,6 +321,18 @@ class Job:
             "waiting for data/model download",
         ]:
             return self.url
+        if self.status in [
+            "failed",
+            "finished",
+            "canceled",
+            "archived",
+            "removed",
+            "removing",
+        ]:
+            raise SpecificationError(
+                "status",
+                f"You can only connect to active jobs.",
+            )
         connection = Connection(
             self.trainml, entity_type="job", id=self.id, entity=self
         )
