@@ -99,6 +99,8 @@ class Model:
     def get_connection_details(self):
         if self._model.get("vpn"):
             details = dict(
+                entity_type="model",
+                project_uuid=self._model.get("project_uuid"),
                 cidr=self._model.get("vpn").get("cidr"),
                 ssh_port=self._model.get("vpn").get("client").get("ssh_port"),
                 input_path=self._model.get("source_uri"),
@@ -109,6 +111,11 @@ class Model:
         return details
 
     async def connect(self):
+        if self.status in ["ready", "failed"]:
+            raise SpecificationError(
+                "status",
+                f"You can only connect to new or downloading models.",
+            )
         connection = Connection(
             self.trainml, entity_type="model", id=self.id, entity=self
         )
